Installation
============

Python version
--------------

SunsetSettings requires Python 3.10 or later.


Installing from PyPI (recommended)
----------------------------------

From a command line prompt, type:

.. code:: shell

  pip install SunsetSettings


Installing from GitHub
----------------------

- Dependencies: install `flit <https://pypi.org/project/flit/>`_:

  .. code:: shell

    pip install flit

- Checkout the code:

  .. code:: shell

    git clone https://github.com/pvaret/SunsetSettings

- Build and install the library:

  .. code:: shell

    cd SunsetSettings ; flit install

That's it!
